@@ -24,12 +24,16 @@ class BassInstrument(Instrument):
 				else:
 					break
 			return [n]
-		elif state["tick"] % (state["resolution"] / 4.0) == \
-				state["resolution"] / 8 and \
-				random() < 0.2 * wild:
+		elif state["resolution"] > 4 and state["tick"] % \
+			(state["resolution"] / 4.0) == \
+			state["resolution"] / 8 and \
+			random() < 0.2 * wild:
 			
 			n = Note(choice(state["chord"]))
-			n.octave_down()
-			n.octave_down()
+			while n > Note("E", 3):
+				if n.octave >= 3:
+					n.octave_down()
+				else:
+					break
 			n.name = notes.diminish(n.name)
 			return [n]
