@@ -3,8 +3,8 @@ from PygameVisualization import PygameVisualization
 from PygameBlockVisualization import PygameBlockVisualization
 from PygameLineVisualization import PygameLineVisualization
 from PygameMixedVisualizations import PygameMixedVisualizations
+from DefaultVisualization import DefaultVisualization
 
-
-__all__ = ['Visualization', 'PygameVisualization', 'PygameBlockVisualization', 'PygameLineVisualization', 'PygameMixedVisualizations']
+__all__ = ['Visualization', 'PygameVisualization', 'PygameBlockVisualization', 'PygameLineVisualization', 'PygameMixedVisualizations', 'DefaultVisualization']
 
 
