@@ -4,13 +4,16 @@ from aboutDialog import Ui_aboutDialog
 from ProgressionDialog import ProgressionDialog
 from InstrumentDialog import InstrumentDialog
 from BlockDialog import BlockDialog
+from UploadDialog import UploadDialog
 from os import path, environ
 from mingus.core import diatonic
 import Progressions
 import Options
+import Movements
+import tempfile
 
 APP_NAME = "qtImproviser"
-APP_VERSION = "0.7"
+APP_VERSION = "0.8"
 
 
 class OptionClass:
@@ -36,7 +39,6 @@ class ImproviserMainWindow(QtGui.QMainWindow):
 		self.ui = Ui_MainWindow()
 		self.ui.setupUi(self)
 		self.fill_combos()
-		self.connect_widgets()
 		self.set_defaults()
 
 	def set_title(self):
@@ -177,8 +179,32 @@ class ImproviserMainWindow(QtGui.QMainWindow):
 		self.connect(self.ui.importprogression,
 			QtCore.SIGNAL("clicked()"),
 			self.import_progression)
+		self.connect(self.ui.movement,
+			QtCore.SIGNAL("highlighted(int)"),
+			self.highlighted_movement)
+
+		if self.loggedin:
+			self.connect(self.ui.uploadbutton,
+				QtCore.SIGNAL("clicked()"),
+				self.upload_song)
+			self.ui.uploadbutton.setEnabled(True)
 		
 
+	def highlighted_movement(self, index):
+		m = getattr(Movements, str(self.ui.movement.itemText(index)))
+		self.set_status(m().__doc__)
+		del m
+
+	def upload_song(self):
+
+		u = UploadDialog(
+			Options.UPLOAD_SONG,
+			Options.get_song_as_text(self.get_options()),
+			self.credentials)
+		u.setWindowTitle("Upload Song") 
+		u.ui.uploadname.setText(self.ui.projectname.text())
+		u.show()
+		u.exec_()
 
 	def set_defaults(self):
 
@@ -192,7 +218,7 @@ class ImproviserMainWindow(QtGui.QMainWindow):
 		# Combo boxes
 		self.ui.resolution.setCurrentIndex(3) # '8'
 		self.ui.key.setCurrentIndex(6) # 'C'
-		self.ui.movement.setCurrentIndex(0)
+		self.ui.movement.setCurrentIndex(self.ui.movement.findText("Movement"))
 		self.ui.bpm.setValue(120)
 		self.ui.wildness.setValue(0.5)
 		self.ui.duration.setValue(1)
@@ -464,22 +490,12 @@ class ImproviserMainWindow(QtGui.QMainWindow):
 		self.ui.wildness.setValue(o.wild)
 
 		# ComboBoxes
-		i = combo_index_by_text(self.ui.resolution, str(o.resolution))
-		if i != -1:
-			self.ui.resolution.setCurrentIndex(i)
-		i = combo_index_by_text(self.ui.key, o.key)
-		if i != -1:
-			self.ui.key.setCurrentIndex(i)
-		i = 0 
-		if hasattr(o, "movement"):
-			i = combo_index_by_text(self.ui.movement, str(o.movement))
-		self.ui.movement.setCurrentIndex(i)
+		self.ui.resolution.setCurrentIndex(self.ui.resolution.findText(str(o.resolution)))
+		self.ui.key.setCurrentIndex(self.ui.key.findText(o.key))
+		self.ui.movement.setCurrentIndex(self.ui.movement.findText(o.movement))
 
-		i = 0
 		if hasattr(o, 'visualization'):
-			i = combo_index_by_text(self.ui.visualization, o.visualization)
-		self.ui.visualization.setCurrentIndex(i)
-
+			self.ui.visualization.setCurrentIndex(self.ui.visualization.findText(o.visualization))
 
 		# CheckBoxes
 		self.ui.swing.setChecked(bool(o.swing))
@@ -619,10 +635,3 @@ class SequencerThread(QtCore.QThread):
 	def run(self):
 		self.seq.play()
 
-
-def combo_index_by_text(combo, text):
-	for x in range(combo.count()):
-		if combo.itemText(x) == text:
-			return x
-	return -1
-
