@@ -3,6 +3,7 @@ from qtGUI.preferencesDialog import Ui_preferencesDialog
 from os import environ, path
 import urllib
 import md5
+import Options
 
 class PreferencesDialog(QtGui.QDialog):
 
@@ -76,17 +77,46 @@ class PreferencesDialog(QtGui.QDialog):
 
 
 	def login(self):
-		return True
+
+		if self.ui.nologin.isChecked():
+			return False
 		params = urllib.urlencode({"name": str(self.ui.username.text()),
-			"pass": md5.new(str(self.ui.password.text())).digest()})
+			"pass": md5.new(str(self.ui.password.text())).hexdigest()})
+
+		
+		if params['name'] == "" or str(self.ui.password.text()) == "":
+			q = QtGui.QMessageBox.warning(self, "Error", "Empty username and/or password", 1, 0)
+			return False
+
 		try:
-			f = urllib.urlopen("http://localhost/improviser/login.php?%s" % params)
+			f = urllib.urlopen(Options.UPLOAD_HOME + "login.php?%s" % params)
 		except:
+			q = QtGui.QMessageBox.critical(self, "Error", "Could not connect to the site.", 1, 0)
 			return False
 		res = f.read()
 		f.close()
-		if res == "OK":
+
+		if res == "":
+			q = QtGui.QMessageBox.critical(self, "Error", "Empty response from server.", 1, 0)
+			return False
+
+
+		keyword = res.split()[0]
+		msg = " ".join(res.split()[1:])
+
+		if keyword == "OK":
 			return True
+		elif keyword == "NEW":
+			q = QtGui.QMessageBox.information(self, "Success", "Created new account '%s'" % str(self.ui.username.text()), 1, 0)
+			return True
+		elif keyword == "INVALID":
+			q = QtGui.QMessageBox.warning(self, "Error", str(msg), 1, 0)
+			return False
+		elif keyword == "ERROR":
+			q = QtGui.QMessageBox.critical(self, "Error", str(msg), 1, 0)
+			return False
+		
+		q = QtGui.QMessageBox.critical(self, "Error", "Invalid response from server.", 1, 0)
 		return False
 
 
@@ -108,6 +138,10 @@ class PreferencesDialog(QtGui.QDialog):
 			   "password": str(self.ui.password.text()),
 			   "login": self.login() }
 
+		if not params['login']:
+			if not self.ui.nologin.isChecked():
+				return
+
 		if no_fluidsynth:
 			self.show_main(params)
 			self.reject()
